@@ -25,7 +25,7 @@ import click
 @click.option('--fix-cache/--no-fix-cache', default=True, help='Fix StarMomentMorph cache')
 @click.option('--fix-multi/--no-fix-multi', default=True, help='Fix MultiPdf level 2')
 @click.option('--offset/--no-offset', default=True, help='Offset likelihood')
-@click.option('--optimize/--no-optimize', default=True, help='Optimize constant terms')
+@click.option('--optimize', type=int, default=2, help='Optimize constant terms')
 @click.option('--max_calls', type=int, default=-1, help='Maximum number of function calls')
 @click.option('--max_iters', type=int, default=-1, help='Maximum number of Minuit iterations')
 @click.option('--parallel', type=int, default=0, help='Parallelize job across different nuisance'+\
@@ -114,7 +114,7 @@ def plot_pulls(**kwargs):
 @click.option('-v', '--verbose',  default=0, help='verbosity')
 @click.option('--max_calls', type=int, default=-1, help='Maximum number of function calls')
 @click.option('--max_iters', type=int, default=-1, help='Maximum number of Minuit iterations')
-@click.option('--optimize/--no-optimize', default=True, help='Optimize constant terms')
+@click.option('--optimize', type=int, default=2, help='Optimize constant terms')
 @click.option('--offset/--no-offset', default=False, help='Offset likelihood')
 @click.option('--parallel', type=int, default=-1, help='Parallelize job across different scan values.'+\
                                                        'Use -1 for N_CPU workers.')
@@ -152,7 +152,7 @@ def likelihood_scan(**kwargs):
 @click.option('--timer/--no_timer', default=False, help='Enable minimizer timer')
 @click.option('-c', '--num_cpu', type=int, default=1, help='Number of CPUs to use per parameter')
 @click.option('--offset/--no-offset', default=True, help='Offset likelihood')
-@click.option('--optimize/--no-optimize', default=True, help='Optimize constant terms')
+@click.option('--optimize', type=int, default=2, help='Optimize constant terms')
 @click.option('--fix-cache/--no-fix-cache', default=True, help='Fix StarMomentMorph cache')
 @click.option('--fix-multi/--no-fix-cache',  default=True, help='Fix MultiPdf level 2')
 @click.option('--max_calls', type=int, default=-1, help='Maximum number of function calls')
