@@ -120,7 +120,7 @@ class AsymptoticCLs(AnalysisObject):
         if math.isnan(val):
             raise ValueError("cannot set poi to nan")
         if ( val > 0 ) and (self.poi.getMax() < val):
-            poi.setMax(2*val)
+            self.poi.setMax(2*val)
         if ( val < 0 ) and (self.poi.getMin() > val):
             self.poi.setMin(2*val)
         self.poi.setVal(val)
@@ -439,7 +439,7 @@ class AsymptoticCLs(AnalysisObject):
             self.LimitTool.setDirection(-1)
         asimov_0_nll = self.summary[0]['nll']
         mu_guess = n*med_limit/math.sqrt(3.84)
-        n_times_sigma = self.get_limit(asimov_0_nll, mu_guess, 'nom_{}'.format(n))
+        n_times_sigma = self.get_limit(asimov_0_nll, mu_guess)
         status = self.global_status
         sigma = n_times_sigma/n
         print('Found N * sigma = {} * {}'.format(n, sigma))
