@@ -129,7 +129,8 @@ class ExtendedMinimizer(object):
                 nll_command_list = self.nll_command_list
             else:
                 nll_command_list = self.parse_nll_commands(nll_command_list)
-            self.nll = self.pdf.createNLL(self.data, nll_command_list)
+            #self.nll = self.pdf.createNLL(self.data, nll_command_list)
+            self.nll = self.pdf.createNLL(self.data, *nll_command_list)
         
     def create_minimizer(self):
         
@@ -155,11 +156,13 @@ class ExtendedMinimizer(object):
                 self.minimizer.setMaxIterations(self.config['max_iters'])
  
     def parse_nll_commands(self, commands:List["ROOT.RooCmdArg"]):
-        nll_command_list = ROOT.RooLinkedList()
-        for command in commands:
-            nll_command_list.Add(command)
-        return nll_command_list
-    
+        # temporary fix for ROOT version below 6.22/06
+        #nll_command_list = ROOT.RooLinkedList()
+        #for command in commands:
+        #    nll_command_list.Add(command)
+        #return nll_command_list
+        return commands
+        
     def configure_nll(self, constrain=None, global_observables=None, **kwargs):
         commands = []
         if 'num_cpu' in kwargs:
