@@ -131,7 +131,7 @@ class ExtendedModel(object):
             name = component.GetName()
             if (component.InheritsFrom(ROOT.RooAbsPdf.Class()) and condition(name)):
                 component.setAttribute("NOCacheAndTrack")
-                print('INFO: Deactivated level 2 constant term optimizatio for {}'.format(name))
+                print('INFO: Deactivated level 2 constant term optimization for {}'.format(name))
             
     def initialize(self):
         if not os.path.exists(self.fname):
