@@ -23,7 +23,7 @@ def evaluate_nll(input_file:str, poi_val:float, poi:str="", vmin:float=10., vmax
                  profile:str="", fix:str="", hesse:bool=False, minos:bool=True, constrain:bool=True, 
                  minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', num_cpu:int=1, binned:bool=True,
                  eps:float=1.0, strategy:int=0, fix_cache:bool=True, fix_multi:bool=True, mpsplit:int=3, 
-                 verbose:int=0, max_calls:int=-1, max_iters:int=-1, optimize:bool=True, offset:bool=False, 
+                 verbose:int=0, max_calls:int=-1, max_iters:int=-1, optimize:int=2, offset:bool=False, 
                  outname:str=None, cache:bool=False):
     if cache:
         cached_result = load_cache(outname)
@@ -113,7 +113,7 @@ def scan_nll(input_file:str, poi_min:float, poi_max:float, poi_step:float, poi:s
              profile:str="", fix:str="", hesse:bool=False, minos:bool=True, constrain:bool=True,
              minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', num_cpu:int=1, binned:bool=True,
              eps:float=1.0, strategy:int=0, fix_cache:bool=True, fix_multi:bool=True, mpsplit:int=3, 
-             verbose:int=0, max_calls:int=-1, max_iters:int=-1, optimize:bool=True, offset:bool=False, parallel:int=8):
+             verbose:int=0, max_calls:int=-1, max_iters:int=-1, optimize:int=2, offset:bool=False, parallel:int=8):
     start_time = time.time()
     points        = np.arange(poi_min, poi_max+poi_step, poi_step)
     unconditional = np.concatenate(([True], np.full((len(points)), False)))
