@@ -53,10 +53,13 @@ class NuisanceParameterHarmonizer(object):
         return matches
     
     @staticmethod
-    def get_suggested_names(source, possibilities, cutoff=0.6):
+    def get_suggested_names(source, possibilities, cutoff=0.6, replace={}):
         suggested_names = {}
         for name in source:
-            matches = difflib.get_close_matches(name, possibilities, n=1, cutoff=cutoff)
+            _name = name
+            for old, new in replace.items():
+                _name = _name.replace(old, new)             
+            matches = difflib.get_close_matches(_name, possibilities, n=1, cutoff=cutoff)
             if matches:
                 suggested_names[name] = matches[0]
         return suggested_names
@@ -160,7 +163,8 @@ class NuisanceParameterHarmonizer(object):
                     names = []
                     for key, value in reference[group]['source'].items():
                         names += value['names']
-                suggested_names = NuisanceParameterHarmonizer.get_suggested_names(selected, names, cutoff)
+                replace = reference[group].get('replace', {})
+                suggested_names = NuisanceParameterHarmonizer.get_suggested_names(selected, names, cutoff, replace)
                 if suggested_names:
                     if 'names' in reference[group]:
                         mappings[group] = suggested_names
