@@ -80,7 +80,7 @@ class NuisanceParameterPull(object):
                    workspace:Optional[str]=None, model_config:Optional[str]=None,
                    minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', 
                    precision:float=0.001, eps:float=1.0, strategy:int=0, 
-                   num_cpu:int=1, offset:bool=True, optimize:bool=True, eigen:bool=False,
+                   num_cpu:int=1, offset:bool=True, optimize:int=2, eigen:bool=False,
                    fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
                    max_iters:int=-1, outdir:str='output', cache=True, logfile_path=None, **kwargs):
         # create output directory if not exists
@@ -269,7 +269,7 @@ class NuisanceParameterPull(object):
                   fix:str='', workspace:Optional[str]=None, model_config:Optional[str]=None,
                   minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', num_cpu:int=1, 
                   binned:bool=1, precision:float=0.001, eps:float=1.0, log_level:str='INFO', eigen:bool=False, 
-                  strategy:int=0, fix_cache:bool=True, fix_multi:bool=True, offset:bool=True, optimize:bool=True,
+                  strategy:int=0, fix_cache:bool=True, fix_multi:bool=True, offset:bool=True, optimize:int=2,
                   parameter:str="", max_calls:int=-1, max_iters:int=-1, parallel:int=0, cache:bool=True, 
                   exclude:str='', **kwargs):
         
